==> spip_4.0.4.orig.tar.xz: plugins-dist/revisions/lang/revisions_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Verschillen tonen',

	// D
	'diff_para_ajoute' => 'Toegevoegde paragraaf',
	'diff_para_deplace' => 'Verplaatste paragraaf',
	'diff_para_supprime' => 'Verwijderde paragraaf',
	'diff_texte_ajoute' => 'Toegevoegde tekst',
	'diff_texte_deplace' => 'Verplaatste tekst',
	'diff_texte_supprime' => 'Verwijderde tekst',
	'differences_versions' => 'Verschillen tussen versie N<sup>r</sup>@id_version@ en versie N<sup>r</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Versie N<sup>r</sup>@version@ terugzetten',
	'icone_suivi_revisions' => 'Opvolging van revisies',
	'info_1_revision' => '1 revisie',
	'info_aucune_revision' => 'Geen revisie',
	'info_historique' => 'Revisies:',
	'info_historique_lien' => 'De geschiedenis van de wijzigingen weergeven',
	'info_historique_titre' => 'Opvolging van de revisies',
	'info_nb_revisions' => '@nb@ wijzigingen',

	// L
	'label_choisir_id_version' => 'Selecteer de te vergelijken versies',
	'label_config_revisions_objets' => 'Op welke objecten wil je revisies activeren:',

	// M
	'message_valider_recuperer_version' => 'Valideer het formulier om deze versie terug te zetten.',

	// O
	'objet_editorial' => 'object',

	// P
	'plugin_update' => 'Plugin "Revisies" te updaten naar versie @version@.',

	// T
	'titre_form_revisions_objets' => 'Revisies activeren',
	'titre_restaurer_version' => 'Een versie terugzetten',
	'titre_revisions' => 'Revisies',

	// V
	'version_deplace_rubrique' => 'Verplaatsen van <b>« @from@ »</b> naar <b>« @to@ »</b>.',
	'version_initiale' => 'Beginversie',
	'voir_differences' => 'Verschillen tonen',
	'voir_mes_revisions' => 'Mijn eigen revisies',
	'voir_revisions' => 'Revisies zien (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Alle revisies'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Verschillen tonen',

	// D
	'diff_para_ajoute' => 'Toegevoegde paragraaf',
	'diff_para_deplace' => 'Verplaatste paragraaf',
	'diff_para_supprime' => 'Verwijderde paragraaf',
	'diff_texte_ajoute' => 'Toegevoegde tekst',
	'diff_texte_deplace' => 'Verplaatste tekst',
	'diff_texte_supprime' => 'Verwijderde tekst',
	'differences_versions' => 'Verschillen tussen versie N<sup>r</sup>@id_version@ en versie N<sup>r</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Versie N<sup>r</sup>@version@ terugzetten',
	'icone_suivi_revisions' => 'Opvolging van revisies',
	'info_1_revision' => '1 revisie',
	'info_aucune_revision' => 'Geen revisie',
	'info_historique' => 'Revisies:',
	'info_historique_lien' => 'De geschiedenis van de wijzigingen weergeven',
	'info_historique_titre' => 'Opvolging van de revisies',
	'info_nb_revisions' => '@nb@ wijzigingen',

	// L
	'label_choisir_id_version' => 'Selecteer de te vergelijken versies',
	'label_config_revisions_objets' => 'Op welke objecten wil je revisies activeren:',

	// M
	'message_valider_recuperer_version' => 'Valideer het formulier om deze versie terug te zetten.',

	// O
	'objet_editorial' => 'object',

	// P
	'plugin_update' => 'Plugin "Revisies" te updaten naar versie @version@.',

	// T
	'titre_form_revisions_objets' => 'Revisies activeren',
	'titre_restaurer_version' => 'Een versie terugzetten',
	'titre_revisions' => 'Revisies',

	// V
	'version_deplace_rubrique' => 'Verplaatsen van <b>« @from@ »</b> naar <b>« @to@ »</b>.',
	'version_initiale' => 'Beginversie',
	'voir_differences' => 'Verschillen tonen',
	'voir_mes_revisions' => 'Mijn eigen revisies',
	'voir_revisions' => 'Revisies zien (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Alle revisies',
];
